@@ -1,9 +1,11 @@
 # -*- coding:utf-8 -*-
 from trdb2py.config import loadConfig
 from trdb2py.indicator import isPriceIndicator, isNeedSecondY
-from trdb2py.trdb2 import (simTradings, getAssetCandles, simTrading, getAssetCandles2, simTradings3)
+from trdb2py.trdb2 import (simTradings, getAssetCandles,
+                           simTrading, getAssetCandles2, simTradings3, getAssetCandles3)
 from trdb2py.utils import str2asset, nextWeekDay, asset2str
 from trdb2py.candlesutils import calcCandlesSimilarity
+from trdb2py.assetsutils import calcAssetsSimilarity
 from trdb2py.timeutils import str2timestamp, getDayInYear, getYearDays, calcYears
 from trdb2py.pdutils import (buildPNLReport, getPNLLastTs, getPNLValueWithTimestamp, mergePNL, mergePNLEx,
                              rmPNLValuesWithTimestamp, getPNLTimestampLowInMonth, getPNLTimestampHighInMonth,
